# 声明
本项目是木兰语言的逆向工程，使用的所有参考信息均从网络公开资料中合法获得。

作者本人不属于任何公司、集体。本项目使用GNU通用公共许可证。对任何人使用此项目产生的任何后果概不负责

本项目是对原木兰语言的逆向工程，部分逻辑完全靠猜想完成，具体代码与原木兰语言的实现没有任何关系，不代表原木兰项目功能、实现方式和代码质量。

### 运行
在 Python 3.8.1 下测试通过. 需事先安装 codegen 和 rply. 

安装此包后, 试运行如下:
```
$ ulang
Welcome to ulang's REPL..
Type 'help' for more informations.
> func 过(年) { println(年+1) }
> 过(2019)
2020
```

### 大事记

- [木兰编程语言基本功能摸索 (一)](https://zhuanlan.zhihu.com/p/103916529)
- [为「木兰」编程语言添加对中文命名标识符的支持](https://zhuanlan.zhihu.com/p/103910116)
- [「MulanRevive」编程语言项目启动](https://zhuanlan.zhihu.com/p/103895446)
